@@ -33,9 +33,11 @@ extern bool flag_devel;
 #include "../icon/x1.xpm"
 #include "../icon/x2.xpm"
 
-#include <stdio.h>
-#include <time.h>
-#include <errno.h>
+#include <cstdio>
+#include <ctime>
+#include <cerrno>
+#include <cstdarg>
+#include <cstring>
 
 // 300% faster than glibc (by fasthyun@magicn.com)
 int x_atoi(const char *sstr)
@@ -61,11 +63,9 @@ QWidget *getQpsWidget()
         if (w->objectName() == "qps")
             return w;
     }
-    return 0;
+    return nullptr;
 }
 
-#include <stdarg.h>
-#include <string.h>
 /*
   ver 0.2
   A simplified vsscanf implementation from Internet
@@ -126,7 +126,7 @@ int mini_sscanf(const char *s1, const char *fmt, ...)
             else if (fmt[1] == '*' && fmt[2] == 's') // skip
             {
                 p = strchr(s, ' '); // 0x20,0x00,0x0A, 123 435 54054
-                if (p == 0)
+                if (p == nullptr)
                 {
                     //	printf("%s : %c [%s]
                     //\n",__FUNCTION__,fmt[1],s);
@@ -204,9 +204,9 @@ int mini_sscanf(const char *s1, const char *fmt, ...)
                 strncpy(sstr, fmt, n);
                 sstr[n] = 0;
                 p = strstr(s, sstr);
-                if (p == 0)
+                if (p == nullptr)
                 {
-                    if (0 and flag_devel)
+                    if (false and flag_devel)
                         printf("%s : can't found [%s] "
                                "in %s\n",
                                __FUNCTION__, sstr, s);
@@ -238,7 +238,7 @@ int mini_sscanf(const char *s1, const char *fmt, ...)
 int fsize(char *fname)
 {
     int size = 0;
-    if (0)
+    if (false)
     {
         // !!! important !! not works with [/proc] , because [/proc/*]
         // always zero
@@ -271,7 +271,7 @@ int fsize(char *fname)
 void msleep(long msec)
 {
 #ifdef LINUX
-    timespec req, remain;
+    timespec req;
     timeval tv;
     req.tv_sec = 0;
     req.tv_nsec = msec * 1000000;
@@ -285,7 +285,7 @@ void msleep(long msec)
 
     tv.tv_sec = 0;
     tv.tv_usec = msec * 1000;
-    select(0, NULL, NULL, NULL, &tv);
+    select(0, nullptr, nullptr, nullptr, &tv);
     return;
 #endif
 }
@@ -325,7 +325,7 @@ CrossBox::CrossBox(const char *text, QWidget *parent) : QCheckBox(text, parent)
 {
 }
 
-void CrossBox::drawButton(QPainter *p)
+void CrossBox::drawButton(QPainter * /*p*/)
 {
     /////	QCheckBox::drawButton(p);
 }
@@ -364,7 +364,7 @@ void TBloon::start_ani()
 
 } */
 
-void TBloon::update(int val)
+void TBloon::update(int /*val*/)
 {
     //`QPoint p=QCursor::pos();
     // qDebug("pos %d %d", p.x(),p.y());
@@ -402,7 +402,7 @@ bool TBloon::eventFilter(QObject *obj, QEvent *event)
     }
     else if (event->type() == QEvent::MouseMove)
     {
-        QMouseEvent *me = static_cast<QMouseEvent *>(event);
+        // QMouseEvent *me = static_cast<QMouseEvent *>(event);
         //	qDebug("Ate key press %d %d", me->x(),me->y());
         //	move(me->x()+5,me->y()+4);
         return false;
@@ -467,7 +467,7 @@ void TFrame::move(int x,int y)
 } */
 
 // QToolTip::showText(e->globalPos(), s);
-void TFrame::showText(QPoint glob_pos, QString str) {}
+void TFrame::showText(QPoint /*glob_pos*/, QString /*str*/) {}
 
 void TFrame::setText(QString str)
 {
@@ -538,7 +538,7 @@ void TFrame::setPos(int x, int y)
     move(x + 16, y + 4);
 }
 
-void TFrame::moveEvent(QMoveEvent *e)
+void TFrame::moveEvent(QMoveEvent * /*e*/)
 {
     // int x=e->pos().x();
     // printf("pos (%d %d) \n",e->pos().x(),e->pos().y());
@@ -551,7 +551,7 @@ void TFrame::setValue(int val)
     update();
 }
 
-void TFrame::showEvent(QShowEvent *event)
+void TFrame::showEvent(QShowEvent * /*event*/)
 {
     opacity = 0.2;
     //	timeLine->start();
@@ -634,7 +634,7 @@ void UFrame::setTitle(QString str)
     title = str;
 }
 
-void UFrame::paintEvent(QPaintEvent *event) {}
+void UFrame::paintEvent(QPaintEvent * /*event*/) {}
 
 QPixmap *letters;
 int pf_height = 9;
@@ -654,13 +654,12 @@ char strong_buff[128];
 class MyThread : public QThread
 {
   public:
-    void run()
+    void run() override
     {
         prctl(PR_SET_NAME, "thread_test123456789");
 
         while (true)
         {
-            int m = 0;
             for (int i = 0; i < 20000; i++)
             {
                 int p = rand() % 120;
@@ -674,7 +673,7 @@ class MyThread : public QThread
 class MyThread2 : public QThread
 {
   public:
-    void run()
+    void run() override
     {
         prctl(PR_SET_NAME, "thread_test987654321");
 
@@ -708,7 +707,6 @@ int pf_write(QPainter *p, int x, int y, const char *str)
 {
     int i, len, n;
     int ch;
-    int sx, sy;
     int x0 = x;
     len = strlen(str);
     for (i = 0; i < len; i++)
@@ -738,7 +736,7 @@ XButton::XButton(QWidget *parent) : QAbstractButton(parent)
     setGeometry(0, 0, w, w);
 }
 
-void XButton::resizeEvent(QResizeEvent *p)
+void XButton::resizeEvent(QResizeEvent * /*p*/)
 {
     int i, h;
     i = height() % 2;
@@ -750,10 +748,9 @@ void XButton::resizeEvent(QResizeEvent *p)
     setFixedSize(h, h);
 }
 
-void XButton::paintEvent(QPaintEvent *event)
+void XButton::paintEvent(QPaintEvent * /*event*/)
 {
     QPainter p(this);
-    int w, h, m;
 
     if (isDown())
         p.drawPixmap(0, 0, *x2);
@@ -785,7 +782,7 @@ void SearchBox::event_cursor_moved(QMouseEvent *e) { move(e->x(), e->y()); }
 
 void SearchBox::event_xbutton_clicked()
 {
-    QKeyEvent ke(QEvent::KeyPress, Qt::Key_Escape, 0); // temp..
+    QKeyEvent ke(QEvent::KeyPress, Qt::Key_Escape, Qt::NoModifier); // temp..
     keyPressEvent(&ke);
 }
 
@@ -906,74 +903,8 @@ void ControlBar::show_thread_clicked()
 
 void ServerAdaptor::accelerate() {}
 
-#include <QDBusConnection>
-
-#define SERVICE_NAME "com.trolltech.qps"
-void dbus_register_server()
-{
-    ServerAdaptor *sv = new ServerAdaptor();
-    QDBusConnection connection = QDBusConnection::sessionBus(); // user only??
-    // QDBusConnection connection = QDBusConnection::systemBus(); //user
-    // only??
-    connection.registerObject("/QPS_OBJ", sv);
-    connection.registerService(SERVICE_NAME); //
-}
-
-#include <QtDebug>
-void qdbus_client()
-{
-    //	connection.connect ( SERVICE_NAME,"path", "interface","name",
-    // QObject *
-    // receiver, const char * slot );
-
-    // QDBusConnection conn =
-    // QDBusConnection::connectToBus(SERVICE_NAME,"hyun");
-
-    QDBusConnection conn = QDBusConnection::sessionBus(); // owner-user
-                                                          // only, hang..
-                                                          // blocked !!!
-
-    QDBusReply<QStringList> reply = conn.interface()->registeredServiceNames();
-
-    if (!reply.isValid())
-    {
-        qDebug() << "qdbus_client Error:" << reply.error().message();
-        //    exit(1);
-    }
-
-    /*
-    foreach (QString name, reply.value())
-    {
-    qDebug() << name;
-            //printf("name %s, value %s \n",qPrintable(name),
-    } */
-
-    if (conn.interface()->isServiceRegistered(SERVICE_NAME))
-    {
-        printf("Qps: Already another QPS is running...\n");
-        exit(1);
-    }
-}
-
-void check_qps_running()
-{
-    // QDBusServer *server=QDBusServer("xaddr"); //peer2peer mode
-    // service,path,interface,name
-    // connect(server, SIGNAL(clicked()), SLOT(event_xbutton_clicked()));
-    // SIGNAL(newConnection ( const QDBusConnection & connection ))
-    // QDBusConnection::connectToBus ("xaddr", "name" );
-
-    //	glib_dbus_getlist();
-    //	glib_dbus_server();
-
-    qdbus_client(); // hang... on root-user
-                    //	printf("D1-1-3\n");
-    dbus_register_server();
-    //	printf("D1-1-6\n");
-}
-
 char *read_proc_file(const char *fname, int pid = -1, int tgid = -1); // Temp
-void init_misc(QWidget *main)
+void init_misc(QWidget * /*main*/)
 {
 
     init_xpm(); // xpm image file load
@@ -999,7 +930,7 @@ void init_misc(QWidget *main)
         char sstr[32] = "pu%s";
         char buffer[128];
 
-        if ((buf = read_proc_file("stat", 1)) == 0)
+        if ((buf = read_proc_file("stat", 1)) == nullptr)
         {
             printf("cant open [%s]\n", "sss");
         }
@@ -1012,7 +943,7 @@ void init_misc(QWidget *main)
     }
 }
 
-QTabWidgetX::QTabWidgetX(QWidget *parent) {}
+QTabWidgetX::QTabWidgetX(QWidget * /*parent*/) {}
 
 void QTabWidgetX::showTab(bool flag)
 {
