@@ -30,13 +30,11 @@
 #include <kstat.h> // kstat_ctl_t
 #endif
 
-#ifndef USING_PCH
 #include <QHash>
 #include <QVector>
 #include <QString>
 #include <QStringList>
 #include <QDir>
-#endif
 
 class Procinfo;
 int read_file(char *name, char *buf, int max);
@@ -237,10 +235,10 @@ class Cat_int : public Category
   public:
     Cat_int(const QString &heading, const QString &explain, int w,
             int Procinfo::*member);
-    virtual int alignment() { return Qt::AlignRight; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return field_width; };
-    virtual int compare(Procinfo *a, Procinfo *b);
+    int alignment() override { return Qt::AlignRight; };
+    QString string(Procinfo *p) override;
+    int width() override { return field_width; };
+    int compare(Procinfo *a, Procinfo *b) override;
 
   protected:
     int Procinfo::*int_member;
@@ -253,10 +251,10 @@ class Cat_memory : public Category
   public:
     Cat_memory(const QString &heading, const QString &explain, int w,
                unsigned long Procinfo::*member);
-    virtual int alignment() { return Qt::AlignRight; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return field_width; };
-    virtual int compare(Procinfo *a, Procinfo *b);
+    int alignment() override { return Qt::AlignRight; };
+    QString string(Procinfo *p) override;
+    int width() override { return field_width; };
+    int compare(Procinfo *a, Procinfo *b) override;
 
   protected:
     unsigned long Procinfo::*uintl_member;
@@ -268,10 +266,10 @@ class Cat_uintl : public Category
   public:
     Cat_uintl(const QString &heading, const QString &explain, int w,
               unsigned long Procinfo::*member);
-    virtual int alignment() { return Qt::AlignRight; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return field_width; };
-    virtual int compare(Procinfo *a, Procinfo *b);
+    int alignment() override { return Qt::AlignRight; };
+    QString string(Procinfo *p) override;
+    int width() override { return field_width; };
+    int compare(Procinfo *a, Procinfo *b) override;
 
   protected:
     unsigned long Procinfo::*uintl_member;
@@ -283,27 +281,27 @@ class Cat_hex : public Cat_uintl
   public:
     Cat_hex(const QString &heading, const QString &explain, int w,
             unsigned long Procinfo::*member);
-    virtual QString string(Procinfo *p);
+    QString string(Procinfo *p) override;
 };
 
 class Cat_swap : public Category
 {
   public:
     Cat_swap(const QString &heading, const QString &explain);
-    virtual int alignment() { return Qt::AlignRight; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return 8; };
-    virtual int compare(Procinfo *a, Procinfo *b);
+    int alignment() override { return Qt::AlignRight; };
+    QString string(Procinfo *p) override;
+    int width() override { return 8; };
+    int compare(Procinfo *a, Procinfo *b) override;
 };
 
 class Cat_string : public Category
 {
   public:
     Cat_string(const QString &heading, const QString &explain,
-               QString Procinfo::*member = 0);
-    virtual int alignment() { return Qt::AlignLeft; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return -9; };
+               QString Procinfo::*member = nullptr);
+    int alignment() override { return Qt::AlignLeft; };
+    QString string(Procinfo *p) override;
+    int width() override { return -9; };
     virtual int gap() { return 8; };
 
   protected:
@@ -314,21 +312,21 @@ class Cat_user : public Cat_string
 {
   public:
     Cat_user(const QString &heading, const QString &explain);
-    virtual QString string(Procinfo *p);
+    QString string(Procinfo *p) override;
 };
 
 class Cat_group : public Cat_string
 {
   public:
     Cat_group(const QString &heading, const QString &explain);
-    virtual QString string(Procinfo *p);
+    QString string(Procinfo *p) override;
 };
 
 class Cat_wchan : public Cat_string
 {
   public:
     Cat_wchan(const QString &heading, const QString &explain);
-    virtual QString string(Procinfo *p);
+    QString string(Procinfo *p) override;
 };
 
 class Cat_dir : public Cat_string
@@ -336,7 +334,7 @@ class Cat_dir : public Cat_string
   public:
     Cat_dir(const QString &heading, const QString &explain, const char *dirname,
             QString Procinfo::*member);
-    virtual QString string(Procinfo *p);
+    QString string(Procinfo *p) override;
 
   protected:
     const char *dir;
@@ -347,16 +345,16 @@ class Cat_cmdline : public Cat_string
 {
   public:
     Cat_cmdline(const QString &heading, const QString &explain);
-    virtual QString string(Procinfo *p);
+    QString string(Procinfo *p) override;
 };
 
 class Cat_state : public Category
 {
   public:
     Cat_state(const QString &heading, const QString &explain);
-    virtual int alignment() { return Qt::AlignLeft; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return 6; };
+    int alignment() override { return Qt::AlignLeft; };
+    QString string(Procinfo *p) override;
+    int width() override { return 6; };
     virtual int gap() { return 8; };
 };
 
@@ -364,21 +362,21 @@ class Cat_policy : public Category
 {
   public:
     Cat_policy(const QString &heading, const QString &explain);
-    virtual int alignment() { return Qt::AlignLeft; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return 3; };
+    int alignment() override { return Qt::AlignLeft; };
+    QString string(Procinfo *p) override;
+    int width() override { return 3; };
     virtual int gap() { return 8; };
-    virtual int compare(Procinfo *a, Procinfo *b);
+    int compare(Procinfo *a, Procinfo *b) override;
 };
 
 class Cat_rtprio : public Category
 {
   public:
     Cat_rtprio(const QString &heading, const QString &explain);
-    virtual int alignment() { return Qt::AlignRight; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return 5; };
-    virtual int compare(Procinfo *a, Procinfo *b);
+    int alignment() override { return Qt::AlignRight; };
+    QString string(Procinfo *p) override;
+    int width() override { return 5; };
+    int compare(Procinfo *a, Procinfo *b) override;
 };
 
 #ifdef LINUX
@@ -386,19 +384,19 @@ class Cat_tms : public Category
 {
   public:
     Cat_tms(const QString &heading, const QString &explain);
-    virtual int alignment() { return Qt::AlignRight; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return 5; };
-    virtual int compare(Procinfo *a, Procinfo *b);
+    int alignment() override { return Qt::AlignRight; };
+    QString string(Procinfo *p) override;
+    int width() override { return 5; };
+    int compare(Procinfo *a, Procinfo *b) override;
 };
 
 class Cat_affcpu : public Category
 {
   public:
     Cat_affcpu(const QString &heading, const QString &explain);
-    virtual int alignment() { return Qt::AlignRight; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return 8; };
+    int alignment() override { return Qt::AlignRight; };
+    QString string(Procinfo *p) override;
+    int width() override { return 8; };
     // virtual int compare(Procinfo *a, Procinfo *b);
 };
 #endif
@@ -407,20 +405,20 @@ class Cat_time : public Category
 {
   public:
     Cat_time(const QString &heading, const QString &explain);
-    virtual int alignment() { return Qt::AlignRight; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return 7; };
-    virtual int compare(Procinfo *a, Procinfo *b);
+    int alignment() override { return Qt::AlignRight; };
+    QString string(Procinfo *p) override;
+    int width() override { return 7; };
+    int compare(Procinfo *a, Procinfo *b) override;
 };
 
 class Cat_start : public Category
 {
   public:
     Cat_start(const QString &heading, const QString &explain);
-    virtual int alignment() { return Qt::AlignRight; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return 8; };
-    virtual int compare(Procinfo *a, Procinfo *b);
+    int alignment() override { return Qt::AlignRight; };
+    QString string(Procinfo *p) override;
+    int width() override { return 8; };
+    int compare(Procinfo *a, Procinfo *b) override;
 };
 
 class Cat_percent : public Category
@@ -428,10 +426,10 @@ class Cat_percent : public Category
   public:
     Cat_percent(const QString &heading, const QString &explain, int w,
                 float Procinfo::*member);
-    virtual int alignment() { return Qt::AlignRight; };
-    virtual QString string(Procinfo *p);
-    virtual int width() { return field_width; };
-    virtual int compare(Procinfo *a, Procinfo *b);
+    int alignment() override { return Qt::AlignRight; };
+    QString string(Procinfo *p) override;
+    int width() override { return field_width; };
+    int compare(Procinfo *a, Procinfo *b) override;
 
   protected:
     float Procinfo::*float_member;
@@ -442,7 +440,7 @@ class Cat_tty : public Cat_string
 {
   public:
     Cat_tty(const QString &heading, const QString &explain);
-    virtual QString string(Procinfo *p);
+    QString string(Procinfo *p) override;
 };
 
 #define CPU_TIMES(cpu, kind) cpu_times_vec[cpu * CPUTIMES + kind]
@@ -501,7 +499,7 @@ class Procinfo // Process Infomation
 
     bool first_run;        // for optimization
     char hashstr[128 * 8]; // cache
-    int hashlen;
+    size_t hashlen;
     int hashcmp(char *str);
 
     QString command;   // COMMAND
@@ -540,11 +538,11 @@ class Procinfo // Process Infomation
     unsigned long cmajflt;
 #endif
 
-    unsigned long io_read;       // byte, testing
-    unsigned long io_write;      // testing
+    unsigned long io_read;       // KB
+    unsigned long io_write;      // KB
     unsigned long io_read_KBps;  // K byte/sec
     unsigned long io_write_KBps; // K byte/sec
-    unsigned long io_read_prev, io_write_prev;
+    unsigned long io_read_prev, io_write_prev; // KB
 
     unsigned long flags; //?
     unsigned long minflt;
@@ -816,9 +814,7 @@ class Procview : public Proc
     void setTreeMode(bool b);
     void saveCOMMANDFIELD();
 
-#ifndef GTK
     Procinfo *getProcinfoByPID(int pid) { return procs.value(pid, NULL); };
-#endif
 
     QVector<Procinfo *> linear_procs; // this is linear_proc_list for viewer
 
@@ -864,9 +860,9 @@ class Procview : public Proc
 
     int idxF_CMD; ////Test
     QStringList customfields;
+    QList<QVariant> customFieldIDs;
     static int custom_fields[64];
     // lists of fields to be used for different views, terminated by -1:
-    static int mini_fields[]; // for mobile
     static int basic_fields[];
     static int jobs_fields[];
     static int mem_fields[];
